@@ -9,15 +9,11 @@
   (error "The NESL/VCODE interface has not been implemented ~
           for the Lisp you are using."))
 
-(let* (#+(or allegro excl)
-       (obj-tailer ".fasl")
-       #+lucid
-       (obj-tailer ".sbin")
-       (src-dir (concatenate 'string *NESL-PATH* "src/"))
+(let* ((src-dir (concatenate 'string *NESL-PATH* "src/"))
        (obj-dir (concatenate 'string *NESL-PATH* "bin/")))
   (flet ((comp-file (name &key needs)
 	   (let ((src-file (concatenate 'string src-dir name ".lisp"))
-		 (obj-file (concatenate 'string obj-dir name obj-tailer)))
+		 (obj-file (concatenate 'string obj-dir name *obj-tailer*)))
 	     (when (not (probe-file src-file))
 		   (error "No source file ~a." src-file))
 	     (when (or (not (probe-file obj-file))
@@ -27,19 +23,18 @@
 	       (compile-file src-file :output-file obj-file)))))
     (comp-file "packages")
     (load (concatenate 'string src-dir "packages.lisp"))
-    (comp-file "definitions")
+    (comp-file "funspec")
+    (load (concatenate 'string src-dir "funspec.lisp"))
     (comp-file "free")
+    (comp-file "type")
+    (comp-file "type-check")
     (comp-file "trans")
     (comp-file "ptrans")
-    (comp-file "type-check")
     (comp-file "output")
-    (comp-file "dispatch")
     (comp-file "run-vcode")
-    (comp-file "config")
     (comp-file "vcode-lisp")
-    (comp-file "doc")
-    ;;#+(or allegro excl)
-    ;;(comp-file "xplot" :needs "/usr/misc/.allegro/lib/code/clx")
+    (comp-file "defop")
+    (comp-file "read-eval-print")
 
     (when (probe-file "vcode/Makefile")
        (format t "~%; Compiling CVL and VCODE~%~%")
