@@ -30,16 +30,6 @@
 #include "vcode.h"
 #include "vstack.h"
 
-/* data structures for constant pool */
-typedef struct const_pool_entry {
-    int *vector;                /* vector of values */
-    vb_t *vb;        		/* vb for constant */
-    TYPE type;                  /* type of the constant */
-    int len;
-} const_pool_entry_t;
-
-extern const_pool_entry_t *const_pool;
-
 extern int const_begin();
 extern void const_new_val();
 extern void const_string();
