@@ -189,6 +189,9 @@ static void main_loop()
     CVL_init(0);			/* safety mode off -- fast'n'deadly */
 #endif DEBUG
 #endif CM2
+#ifdef CM5
+    CVL_init();
+#endif
 
     assert(ok_vcode_table());		/* This doesn't do anything yet */
     stack_init();
@@ -673,6 +676,9 @@ static void main_loop()
 #ifdef CM2
     CVL_quit();
 #endif CM2
+#ifdef CM5
+    CVL_quit();
+#endif
 }
 
 /* initialize the program counter to location of main, or of first funct */
