@@ -733,7 +733,7 @@ prog_entry_t *pe;
 
     /* check type of filename (strings are stored as ints) */
     if (check_args && (mode_vb->type != Int)) {
-	fprintf(stderr, "vinterp: line %d: FOPEN: second argument not string. \n");
+	fprintf(stderr, "vinterp: line %d: FOPEN: second argument not string. \n", pe->lineno);
 	vinterp_exit(1);
     }
 
